@@ -1,5 +1,6 @@
-#!/bin/sh
-set -e
+#!/bin/bash
+set -Eeuo pipefail
+
 curl --proto '=https' --tlsv1.2 -sSf https://sh.rustup.rs > rustup.sh
 sh rustup.sh -y
 # shellcheck source=/dev/null
@@ -8,4 +9,3 @@ export PATH
 rustc --version
 cargo --version
 
-
