@@ -8,11 +8,10 @@ Example:
 import datetime
 import json
 import sys
-from io import StringIO
 from typing import List
 
 import requests
-from lxml import etree
+from bs4 import BeautifulSoup
 
 hurl_repo_url = "https://github.com/Orange-OpenSource/hurl"
 
@@ -94,9 +93,10 @@ def pulls_from_issues(issues: List[Issue]) -> List[Pull]:
                         saved_pull.tags.append(tag)
                 saved_pull.issues.append(issue.number)
             else:
-                pull.tags = issue.tags
-                pull.issues.append(issue.number)
-                pulls[pull.url] = pull
+                if pull.url.startswith("/Orange-OpenSource/hurl"):
+                    pull.tags = issue.tags
+                    pull.issues.append(issue.number)
+                    pulls[pull.url] = pull
 
     return list(pulls.values())
 
@@ -135,15 +135,14 @@ def get_linked_pulls(issue_number) -> List[Pull]:
 
 
 def webscrapping_linked_pulls(html) -> List[Pull]:
-    parser = etree.HTMLParser()
-    tree = etree.parse(StringIO(html), parser)
-    links = tree.xpath("//development-menu//a")
+    soup = BeautifulSoup(html, "html.parser")
+    links = soup.select("development-menu a")
     pulls = []
     for link in links:
-        url = link.attrib["href"]
+        url = link["href"]
         if url == "/Orange-OpenSource/hurl":
             continue
-        description = "".join(link.itertext()).strip()
+        description = "".join(link.getText()).strip()
         pull = Pull(url, description)
         pulls.append(pull)
     return pulls
@@ -185,7 +184,7 @@ def generate_md(
                 "[#%s](%s/issues/%s)" % (issue, hurl_repo_url, issue)
                 for issue in pull.issues
             )
-            s += "\n\n * %s %s" % (pull.description, issues)
+            s += "\n\n* %s %s" % (pull.description, issues)
 
     s += "\n"
     return s
