@@ -1,5 +1,5 @@
-#!/bin/sh
-set -e
+#!/bin/bash
+set -Eeuo pipefail
 
 PATH="$HOME"/.cargo/bin:$PATH
 export PATH
@@ -9,3 +9,4 @@ cargo build --release --verbose --locked
 package_dir="$(cd target/release ; pwd)"
 echo "Run this if you want to use fresh builded hurl package:"
 echo "  export PATH=$package_dir:$PATH"
+
