@@ -1,6 +1,5 @@
 #!/bin/bash
-set -e
-set -o pipefail
+set -Eeuo pipefail
 
 # Check version
 # A specific version defines both the grammar format and the HTML output
@@ -15,4 +14,5 @@ fi
 cat <<END >hurl.grammar.html
 <link rel="stylesheet" type="text/css" href="style.css">
 END
-grammar <hurl.grammar >>hurl.grammar.html
\ No newline at end of file
+grammar <hurl.grammar >>hurl.grammar.html
+
