@@ -1,4 +1,6 @@
 #!/bin/bash
+set -Eeuo pipefail
+
 # Add ad-hoc tests that can't be easily added in tests_ok/ nor tests_failed/
 
 function assert_equals() {
@@ -11,7 +13,7 @@ function assert_equals() {
 }
 
 echo "Check file not found error"
-actual=$(hurl does_not_exist.hurl 2>&1)
+actual=$(hurl does_not_exist.hurl 2>&1 || true)
 expected="error: hurl: cannot access 'does_not_exist.hurl': No such file or directory"
 assert_equals "$actual" "$expected"
 
@@ -24,3 +26,9 @@ echo "Check stdin"
 actual=$(echo 'GET http://localhost:8000/hello' | hurl)
 expected="Hello World!"
 assert_equals "$actual" "$expected"
+
+echo "Check hurlfmt --color"
+actual=$(echo 'GET http://localhost:8000/hello' | hurlfmt --color)
+expected="[33mGET[0m [32mhttp://localhost:8000/hello[0m"
+assert_equals "$actual" "$expected"
+
