@@ -171,13 +171,13 @@ mod tests {
         }
 
         fn check_num(num: usize, expected: &str) {
-            let text = format!("&#{}", num);
+            let text = format!("&#{num}");
             check(&text, expected);
-            let text = format!("&#{};", num);
+            let text = format!("&#{num};");
             check(&text, expected);
-            let text = format!("&#x{:x}", num);
+            let text = format!("&#x{num:x}");
             check(&text, expected);
-            let text = format!("&#x{:x};", num);
+            let text = format!("&#x{num:x};");
             check(&text, expected);
         }
 
@@ -218,9 +218,9 @@ mod tests {
         ]
         .iter()
         {
-            check(&format!("&#{}", num), &format!("{}", char));
-            check(&format!("&#{} ", num), &format!("{} ", char));
-            check(&format!("&#{}X", num), &format!("{}X", char));
+            check(&format!("&#{num}"), &format!("{char}"));
+            check(&format!("&#{num} "), &format!("{char} "));
+            check(&format!("&#{num}X"), &format!("{char}X"));
         }
 
         // Format &#0001234 (without ending semi-colon)
@@ -234,9 +234,9 @@ mod tests {
         ]
         .iter()
         {
-            check(&format!("&#{:07}", num), &format!("{}", char));
-            check(&format!("&#{:07} ", num), &format!("{} ", char));
-            check(&format!("&#{:07}X", num), &format!("{}X", char));
+            check(&format!("&#{num:07}"), &format!("{char}"));
+            check(&format!("&#{num:07} "), &format!("{char} "));
+            check(&format!("&#{num:07}X"), &format!("{char}X"));
         }
 
         // Format &#1234;
@@ -250,9 +250,9 @@ mod tests {
         ]
         .iter()
         {
-            check(&format!("&#{};", num), &format!("{}", char));
-            check(&format!("&#{}; ", num), &format!("{} ", char));
-            check(&format!("&#{};X", num), &format!("{}X", char));
+            check(&format!("&#{num};"), &format!("{char}"));
+            check(&format!("&#{num}; "), &format!("{char} "));
+            check(&format!("&#{num};X"), &format!("{char}X"));
         }
 
         // Format &#0001234;
@@ -266,9 +266,9 @@ mod tests {
         ]
         .iter()
         {
-            check(&format!("&#{:07};", num), &format!("{}", char));
-            check(&format!("&#{:07}; ", num), &format!("{} ", char));
-            check(&format!("&#{:07};X", num), &format!("{}X", char));
+            check(&format!("&#{num:07};"), &format!("{char}"));
+            check(&format!("&#{num:07}; "), &format!("{char} "));
+            check(&format!("&#{num:07};X"), &format!("{char}X"));
         }
 
         // Format &#x1abc
@@ -282,9 +282,9 @@ mod tests {
         ]
         .iter()
         {
-            check(&format!("&#x{:x}", num), &format!("{}", char));
-            check(&format!("&#x{:x} ", num), &format!("{} ", char));
-            check(&format!("&#x{:x}X", num), &format!("{}X", char));
+            check(&format!("&#x{num:x}"), &format!("{char}"));
+            check(&format!("&#x{num:x} "), &format!("{char} "));
+            check(&format!("&#x{num:x}X"), &format!("{char}X"));
         }
 
         // Format &#x001abc
@@ -298,9 +298,9 @@ mod tests {
         ]
         .iter()
         {
-            check(&format!("&#x{:06x}", num), &format!("{}", char));
-            check(&format!("&#x{:06x} ", num), &format!("{} ", char));
-            check(&format!("&#x{:06x}X", num), &format!("{}X", char));
+            check(&format!("&#x{num:06x}"), &format!("{char}"));
+            check(&format!("&#x{num:06x} "), &format!("{char} "));
+            check(&format!("&#x{num:06x}X"), &format!("{char}X"));
         }
 
         // Format &#x1abc;
@@ -314,9 +314,9 @@ mod tests {
         ]
         .iter()
         {
-            check(&format!("&#x{:x};", num), &format!("{}", char));
-            check(&format!("&#x{:x}; ", num), &format!("{} ", char));
-            check(&format!("&#x{:x};X", num), &format!("{}X", char));
+            check(&format!("&#x{num:x};"), &format!("{char}"));
+            check(&format!("&#x{num:x}; "), &format!("{char} "));
+            check(&format!("&#x{num:x};X"), &format!("{char}X"));
         }
 
         // Format &#x001abc;
@@ -330,9 +330,9 @@ mod tests {
         ]
         .iter()
         {
-            check(&format!("&#x{:06x};", num), &format!("{}", char));
-            check(&format!("&#x{:06x}; ", num), &format!("{} ", char));
-            check(&format!("&#x{:06x};X", num), &format!("{}X", char));
+            check(&format!("&#x{num:06x};"), &format!("{char}"));
+            check(&format!("&#x{num:06x}; "), &format!("{char} "));
+            check(&format!("&#x{num:06x};X"), &format!("{char}X"));
         }
 
         // Format &#x1ABC
@@ -346,9 +346,9 @@ mod tests {
         ]
         .iter()
         {
-            check(&format!("&#x{:X}", num), &format!("{}", char));
-            check(&format!("&#x{:X} ", num), &format!("{} ", char));
-            check(&format!("&#x{:X}X", num), &format!("{}X", char));
+            check(&format!("&#x{num:X}"), &format!("{char}"));
+            check(&format!("&#x{num:X} "), &format!("{char} "));
+            check(&format!("&#x{num:X}X"), &format!("{char}X"));
         }
 
         // Format &#x001ABC
@@ -362,9 +362,9 @@ mod tests {
         ]
         .iter()
         {
-            check(&format!("&#x{:06X}", num), &format!("{}", char));
-            check(&format!("&#x{:06X} ", num), &format!("{} ", char));
-            check(&format!("&#x{:06X}X", num), &format!("{}X", char));
+            check(&format!("&#x{num:06X}"), &format!("{char}"));
+            check(&format!("&#x{num:06X} "), &format!("{char} "));
+            check(&format!("&#x{num:06X}X"), &format!("{char}X"));
         }
 
         // Format &#x1ABC;
@@ -378,9 +378,9 @@ mod tests {
         ]
         .iter()
         {
-            check(&format!("&#x{:X};", num), &format!("{}", char));
-            check(&format!("&#x{:X}; ", num), &format!("{} ", char));
-            check(&format!("&#x{:X};X", num), &format!("{}X", char));
+            check(&format!("&#x{num:X};"), &format!("{char}"));
+            check(&format!("&#x{num:X}; "), &format!("{char} "));
+            check(&format!("&#x{num:X};X"), &format!("{char}X"));
         }
 
         // Format &#x001ABC;
@@ -394,9 +394,9 @@ mod tests {
         ]
         .iter()
         {
-            check(&format!("&#x{:06X};", num), &format!("{}", char));
-            check(&format!("&#x{:06X}; ", num), &format!("{} ", char));
-            check(&format!("&#x{:06X};X", num), &format!("{}X", char));
+            check(&format!("&#x{num:06X};"), &format!("{char}"));
+            check(&format!("&#x{num:06X}; "), &format!("{char} "));
+            check(&format!("&#x{num:06X};X"), &format!("{char}X"));
         }
 
         // Format &#X1abc;
@@ -410,9 +410,9 @@ mod tests {
         ]
         .iter()
         {
-            check(&format!("&#X{:x};", num), &format!("{}", char));
-            check(&format!("&#X{:x}; ", num), &format!("{} ", char));
-            check(&format!("&#X{:x};X", num), &format!("{}X", char));
+            check(&format!("&#X{num:x};"), &format!("{char}"));
+            check(&format!("&#X{num:x}; "), &format!("{char} "));
+            check(&format!("&#X{num:x};X"), &format!("{char}X"));
         }
 
         // Format &#X001abc;
@@ -426,9 +426,9 @@ mod tests {
         ]
         .iter()
         {
-            check(&format!("&#X{:06x};", num), &format!("{}", char));
-            check(&format!("&#X{:06x}; ", num), &format!("{} ", char));
-            check(&format!("&#X{:06x};X", num), &format!("{}X", char));
+            check(&format!("&#X{num:06x};"), &format!("{char}"));
+            check(&format!("&#X{num:06x}; "), &format!("{char} "));
+            check(&format!("&#X{num:06x};X"), &format!("{char}X"));
         }
 
         // Check invalid code points
@@ -466,7 +466,7 @@ mod tests {
         // Check triple adjacent charrefs
         for e in ["&quot", "&#34", "&#x22", "&#X22"] {
             // check(&e.repeat(3), "\"\"\"");
-            check(&format!("{};", e).repeat(3), "\"\"\"")
+            check(&format!("{e};").repeat(3), "\"\"\"")
         }
 
         // Check that the case is respected
