@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2022 Orange
+ * Copyright (C) 2023 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -29,6 +29,7 @@ use super::query::eval_query;
 use super::value::Value;
 
 impl AssertResult {
+    /// Evaluates an assert and returns `None` if assert is succeeded or an `Error` if failed.
     pub fn error(&self) -> Option<Error> {
         match self {
             AssertResult::Version {
@@ -36,7 +37,10 @@ impl AssertResult {
                 expected,
                 source_info,
             } => {
-                if expected.as_str() == "*" || actual == expected {
+                if expected.as_str() == "HTTP"
+                    || expected.as_str() == "HTTP/*"
+                    || actual == expected
+                {
                     None
                 } else {
                     Some(Error {
@@ -150,7 +154,7 @@ pub fn eval_assert(
             }),
             Some(value) => {
                 let filters = assert.filters.iter().map(|(_, f)| f.clone()).collect();
-                match eval_filters(&filters, &value, variables) {
+                match eval_filters(&filters, &value, variables, true) {
                     Ok(value) => Ok(Some(value)),
                     Err(e) => Err(e),
                 }
