@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2022 Orange
+ * Copyright (C) 2023 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -46,7 +46,7 @@ pub fn eval_capture(
         }
         Some(value) => {
             let filters = capture.filters.iter().map(|(_, f)| f.clone()).collect();
-            eval_filters(&filters, &value, variables)?
+            eval_filters(&filters, &value, variables, false)?
         }
     };
     Ok(CaptureResult {
@@ -181,7 +181,7 @@ pub mod tests {
                 value: QueryValue::Xpath {
                     space0: whitespace.clone(),
                     expr: Template {
-                        quotes: true,
+                        delimiter: Some('"'),
                         elements: vec![TemplateElement::String {
                             value: "//user".to_string(),
                             encoded: "//user".to_string(),
