@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2022 Orange
+ * Copyright (C) 2023 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -61,6 +61,8 @@ pub enum ParseError {
     OddNumberOfHexDigits,
     UrlIllegalCharacter(char),
     InvalidOption,
+    Multiline,
+    GraphQlVariables,
 }
 
 impl Error {
