@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2022 Orange
+ * Copyright (C) 2023 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,6 +15,7 @@
  * limitations under the License.
  *
  */
+use crate::ast::VersionValue::VersionAny;
 use crate::ast::*;
 
 use super::bytes::*;
@@ -134,7 +135,7 @@ fn method(reader: &mut Reader) -> ParseResult<'static, Method> {
     }
     let start = reader.state.clone();
     let name = reader.read_while(|c| c.is_alphanumeric());
-    let available_methods = vec![
+    let available_methods = [
         ("GET", Method::Get),
         ("HEAD", Method::Head),
         ("POST", Method::Post),
@@ -144,9 +145,16 @@ fn method(reader: &mut Reader) -> ParseResult<'static, Method> {
         ("OPTIONS", Method::Options),
         ("TRACE", Method::Trace),
         ("PATCH", Method::Patch),
+        ("LINK", Method::Link),
+        ("UNLINK", Method::Unlink),
+        ("PURGE", Method::Purge),
+        ("LOCK", Method::Lock),
+        ("UNLOCK", Method::Unlock),
+        ("PROPFIND", Method::Propfind),
+        ("VIEW", Method::View),
     ];
 
-    for (s, method) in available_methods {
+    for (s, method) in available_methods.into_iter() {
         if name == s {
             return Ok(method);
         }
@@ -160,32 +168,52 @@ fn method(reader: &mut Reader) -> ParseResult<'static, Method> {
 }
 
 fn version(reader: &mut Reader) -> ParseResult<'static, Version> {
-    try_literal("HTTP/", reader)?;
-    let available_version = vec![
-        ("1.0", VersionValue::Version1),
-        ("1.1", VersionValue::Version11),
-        ("2", VersionValue::Version2),
-        ("*", VersionValue::VersionAny),
-    ];
     let start = reader.state.clone();
-    for (s, value) in available_version {
-        if try_literal(s, reader).is_ok() {
-            return Ok(Version {
-                value,
-                source_info: SourceInfo::new(
-                    start.pos.line,
-                    start.pos.column,
-                    reader.state.pos.line,
-                    reader.state.pos.column,
-                ),
-            });
+    try_literal("HTTP", reader)?;
+
+    let next_c = reader.peek();
+    match next_c {
+        Some('/') => {
+            let available_version = vec![
+                ("/1.0", VersionValue::Version1),
+                ("/1.1", VersionValue::Version11),
+                ("/2", VersionValue::Version2),
+                ("/*", VersionValue::VersionAnyLegacy),
+            ];
+            for (s, value) in available_version.iter() {
+                if try_literal(s, reader).is_ok() {
+                    return Ok(Version {
+                        value: value.clone(),
+                        source_info: SourceInfo::new(
+                            start.pos.line,
+                            start.pos.column,
+                            reader.state.pos.line,
+                            reader.state.pos.column,
+                        ),
+                    });
+                }
+            }
+            Err(Error {
+                pos: start.pos,
+                recoverable: false,
+                inner: ParseError::Version {},
+            })
         }
+        Some(' ') => Ok(Version {
+            value: VersionAny,
+            source_info: SourceInfo::new(
+                start.pos.line,
+                start.pos.column,
+                reader.state.pos.line,
+                reader.state.pos.column,
+            ),
+        }),
+        _ => Err(Error {
+            pos: start.pos,
+            recoverable: false,
+            inner: ParseError::Version {},
+        }),
     }
-    Err(Error {
-        pos: start.pos,
-        recoverable: false,
-        inner: ParseError::Version {},
-    })
 }
 
 fn status(reader: &mut Reader) -> ParseResult<'static, Status> {
@@ -199,7 +227,7 @@ fn status(reader: &mut Reader) -> ParseResult<'static, Status> {
                     pos: start,
                     recoverable: false,
                     inner: ParseError::Status {},
-                })
+                });
             }
         },
     };
@@ -300,7 +328,7 @@ mod tests {
                     value: String::from("http://google.fr"),
                     encoded: String::from("http://google.fr"),
                 }],
-                quotes: false,
+                delimiter: None,
                 source_info: SourceInfo::new(1, 5, 1, 21),
             },
             line_terminator0: LineTerminator {
@@ -338,7 +366,7 @@ mod tests {
                     value: String::from("http://google.fr"),
                     encoded: String::from("http://google.fr"),
                 }],
-                quotes: false,
+                delimiter: None,
                 source_info: SourceInfo::new(1, 6, 1, 22),
             },
             line_terminator0: LineTerminator {
@@ -385,20 +413,24 @@ mod tests {
                     value: String::from(""),
                     source_info: SourceInfo::new(2, 1, 2, 1),
                 },
-                value: Bytes::RawString(RawString {
+                value: Bytes::MultilineString(MultilineString::Text(Text {
+                    space: Whitespace {
+                        value: "".to_string(),
+                        source_info: SourceInfo::new(2, 4, 2, 4),
+                    },
                     newline: Whitespace {
-                        value: "\n".to_string(),
                         source_info: SourceInfo::new(2, 4, 3, 1),
+                        value: "\n".to_string(),
                     },
                     value: Template {
                         elements: vec![TemplateElement::String {
                             value: String::from("Hello World!\n"),
                             encoded: String::from("Hello World!\n"),
                         }],
-                        quotes: false,
+                        delimiter: None,
                         source_info: SourceInfo::new(3, 1, 4, 1),
                     },
-                }),
+                })),
                 line_terminator0: LineTerminator {
                     space0: Whitespace {
                         value: "".to_string(),
@@ -421,28 +453,26 @@ mod tests {
         assert_eq!(r.method, Method::Post);
         assert_eq!(
             r.body.unwrap().value,
-            Bytes::Json {
-                value: JsonValue::List {
-                    space0: "".to_string(),
-                    elements: vec![
-                        JsonListElement {
-                            space0: "".to_string(),
-                            value: JsonValue::Number("1".to_string()),
-                            space1: "".to_string(),
-                        },
-                        JsonListElement {
-                            space0: "".to_string(),
-                            value: JsonValue::Number("2".to_string()),
-                            space1: "".to_string(),
-                        },
-                        JsonListElement {
-                            space0: "".to_string(),
-                            value: JsonValue::Number("3".to_string()),
-                            space1: "".to_string(),
-                        },
-                    ],
-                }
-            }
+            Bytes::Json(JsonValue::List {
+                space0: "".to_string(),
+                elements: vec![
+                    JsonListElement {
+                        space0: "".to_string(),
+                        value: JsonValue::Number("1".to_string()),
+                        space1: "".to_string(),
+                    },
+                    JsonListElement {
+                        space0: "".to_string(),
+                        value: JsonValue::Number("2".to_string()),
+                        space1: "".to_string(),
+                    },
+                    JsonListElement {
+                        space0: "".to_string(),
+                        value: JsonValue::Number("3".to_string()),
+                        space1: "".to_string(),
+                    },
+                ],
+            })
         );
 
         let mut reader = Reader::init("POST http://localhost:8000/post-json-string\n\"Hello\"");
@@ -450,16 +480,14 @@ mod tests {
         assert_eq!(r.method, Method::Post);
         assert_eq!(
             r.body.unwrap().value,
-            Bytes::Json {
-                value: JsonValue::String(Template {
-                    quotes: true,
-                    elements: vec![TemplateElement::String {
-                        value: "Hello".to_string(),
-                        encoded: "Hello".to_string(),
-                    }],
-                    source_info: SourceInfo::new(2, 2, 2, 7),
-                })
-            }
+            Bytes::Json(JsonValue::String(Template {
+                delimiter: Some('"'),
+                elements: vec![TemplateElement::String {
+                    value: "Hello".to_string(),
+                    encoded: "Hello".to_string(),
+                }],
+                source_info: SourceInfo::new(2, 2, 2, 7),
+            }))
         );
 
         let mut reader = Reader::init("POST http://localhost:8000/post-json-number\n100");
@@ -467,9 +495,7 @@ mod tests {
         assert_eq!(r.method, Method::Post);
         assert_eq!(
             r.body.unwrap().value,
-            Bytes::Json {
-                value: JsonValue::Number("100".to_string())
-            }
+            Bytes::Json(JsonValue::Number("100".to_string()))
         );
     }
 
@@ -514,7 +540,7 @@ mod tests {
 
         let mut reader = Reader::init("HTTP/1. 200");
         let error = version(&mut reader).err().unwrap();
-        assert_eq!(error.pos, Pos { line: 1, column: 6 });
+        assert_eq!(error.pos, Pos { line: 1, column: 1 });
     }
 
     #[test]
@@ -530,7 +556,6 @@ mod tests {
         let mut reader = Reader::init("xxx");
         let result = status(&mut reader);
         assert!(result.is_err());
-        // assert!(result.err().unwrap().pos, Pos { line: 1, column: 1 });
     }
 
     #[test]
@@ -540,28 +565,26 @@ mod tests {
         assert_eq!(b.line_terminators.len(), 0);
         assert_eq!(
             b.value,
-            Bytes::Json {
-                value: JsonValue::List {
-                    space0: "".to_string(),
-                    elements: vec![
-                        JsonListElement {
-                            space0: "".to_string(),
-                            value: JsonValue::Number("1".to_string()),
-                            space1: "".to_string(),
-                        },
-                        JsonListElement {
-                            space0: "".to_string(),
-                            value: JsonValue::Number("2".to_string()),
-                            space1: "".to_string(),
-                        },
-                        JsonListElement {
-                            space0: "".to_string(),
-                            value: JsonValue::Number("3".to_string()),
-                            space1: "".to_string(),
-                        },
-                    ],
-                }
-            }
+            Bytes::Json(JsonValue::List {
+                space0: "".to_string(),
+                elements: vec![
+                    JsonListElement {
+                        space0: "".to_string(),
+                        value: JsonValue::Number("1".to_string()),
+                        space1: "".to_string(),
+                    },
+                    JsonListElement {
+                        space0: "".to_string(),
+                        value: JsonValue::Number("2".to_string()),
+                        space1: "".to_string(),
+                    },
+                    JsonListElement {
+                        space0: "".to_string(),
+                        value: JsonValue::Number("3".to_string()),
+                        space1: "".to_string(),
+                    },
+                ],
+            })
         );
         assert_eq!(reader.state.cursor, 8);
 
@@ -570,12 +593,10 @@ mod tests {
         assert_eq!(b.line_terminators.len(), 0);
         assert_eq!(
             b.value,
-            Bytes::Json {
-                value: JsonValue::Object {
-                    space0: "".to_string(),
-                    elements: vec![],
-                }
-            }
+            Bytes::Json(JsonValue::Object {
+                space0: "".to_string(),
+                elements: vec![],
+            })
         );
         assert_eq!(reader.state.cursor, 2);
 
@@ -584,12 +605,10 @@ mod tests {
         assert_eq!(b.line_terminators.len(), 1);
         assert_eq!(
             b.value,
-            Bytes::Json {
-                value: JsonValue::Object {
-                    space0: "".to_string(),
-                    elements: vec![],
-                }
-            }
+            Bytes::Json(JsonValue::Object {
+                space0: "".to_string(),
+                elements: vec![],
+            })
         );
         assert_eq!(reader.state.cursor, 24);
 
