@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2022 Orange
+ * Copyright (C) 2023 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -68,10 +68,9 @@ pub fn unquoted_template(reader: &mut Reader) -> ParseResult<'static, Template>
         },
         chars,
     };
-    let quotes = false;
     let elements = template::templatize(encoded_string)?;
     Ok(Template {
-        quotes,
+        delimiter: None,
         elements,
         source_info: SourceInfo {
             start: start.pos,
@@ -104,6 +103,7 @@ pub fn unquoted_string_key(reader: &mut Reader) -> ParseResult<'static, EncodedS
                                 || c == '['
                                 || c == ']'
                                 || c == '@'
+                                || c == '$'
                             {
                                 value.push(c);
                                 encoded.push_str(reader.from(save.cursor).as_str())
@@ -142,7 +142,7 @@ pub fn unquoted_string_key(reader: &mut Reader) -> ParseResult<'static, EncodedS
     })
 }
 
-// todo should return an EncodedString
+// TODO: should return an EncodedString
 // (decoding escape sequence)
 pub fn quoted_string(reader: &mut Reader) -> ParseResult<'static, String> {
     literal("\"", reader)?;
@@ -152,7 +152,6 @@ pub fn quoted_string(reader: &mut Reader) -> ParseResult<'static, String> {
 }
 
 pub fn quoted_template(reader: &mut Reader) -> ParseResult<'static, Template> {
-    let quotes = true;
     let start = reader.state.clone().pos;
     let mut end = start.clone();
     try_literal("\"", reader)?;
@@ -185,7 +184,50 @@ pub fn quoted_template(reader: &mut Reader) -> ParseResult<'static, Template> {
     };
     let elements = template::templatize(encoded_string)?;
     Ok(Template {
-        quotes,
+        delimiter: Some('"'),
+        elements,
+        source_info: SourceInfo {
+            start,
+            end: reader.state.pos.clone(),
+        },
+    })
+}
+
+pub fn backtick_template(reader: &mut Reader) -> ParseResult<'static, Template> {
+    let delimiter = Some('`');
+    let start = reader.state.clone().pos;
+    let mut end = start.clone();
+    try_literal("`", reader)?;
+    let mut chars = vec![];
+    loop {
+        let pos = reader.state.pos.clone();
+        let save = reader.state.clone();
+        match any_char(vec!['`', '\n'], reader) {
+            Err(e) => {
+                if e.recoverable {
+                    reader.state = save;
+                    break;
+                } else {
+                    return Err(e);
+                }
+            }
+            Ok((c, s)) => {
+                chars.push((c, s, pos));
+                end = reader.state.clone().pos;
+            }
+        }
+    }
+    literal("`", reader)?;
+    let encoded_string = template::EncodedString {
+        source_info: SourceInfo {
+            start: start.clone(),
+            end,
+        },
+        chars,
+    };
+    let elements = template::templatize(encoded_string)?;
+    Ok(Template {
+        delimiter,
         elements,
         source_info: SourceInfo {
             start,
@@ -238,6 +280,7 @@ fn escape_char(reader: &mut Reader) -> ParseResult<'static, char> {
     match reader.read() {
         Some('#') => Ok('#'),
         Some('"') => Ok('"'),
+        Some('`') => Ok('`'),
         Some('\\') => Ok('\\'),
         Some('/') => Ok('/'),
         Some('b') => Ok('\x08'),
@@ -294,24 +337,12 @@ mod tests {
         assert_eq!(
             unquoted_template(&mut reader).unwrap(),
             Template {
-                quotes: false,
+                delimiter: None,
                 elements: vec![],
                 source_info: SourceInfo::new(1, 1, 1, 1),
             }
         );
         assert_eq!(reader.state.cursor, 0);
-
-        // let mut reader = Reader::init(" hi");
-        // assert_eq!(
-        //     unquoted_template(&mut reader).unwrap(),
-        //     Template {
-        //         quotes: false,
-        //         elements: vec![],
-        //         source_info: SourceInfo::init(1, 1, 1, 1),
-        //     }
-        // );
-        //
-        // assert_eq!(reader.state.cursor, 0);
     }
 
     #[test]
@@ -320,7 +351,7 @@ mod tests {
         assert_eq!(
             unquoted_template(&mut reader).unwrap(),
             Template {
-                quotes: false,
+                delimiter: None,
                 elements: vec![TemplateElement::String {
                     value: "a".to_string(),
                     encoded: "a".to_string(),
@@ -337,7 +368,7 @@ mod tests {
         assert_eq!(
             unquoted_template(&mut reader).unwrap(),
             Template {
-                quotes: false,
+                delimiter: None,
                 elements: vec![TemplateElement::String {
                     value: "a#".to_string(),
                     encoded: "a\\u{23}".to_string(),
@@ -354,7 +385,7 @@ mod tests {
         assert_eq!(
             unquoted_template(&mut reader).unwrap(),
             Template {
-                quotes: false,
+                delimiter: None,
                 elements: vec![TemplateElement::String {
                     value: "\"hi\"".to_string(),
                     encoded: "\"hi\"".to_string(),
@@ -371,7 +402,7 @@ mod tests {
         assert_eq!(
             unquoted_template(&mut reader).unwrap(),
             Template {
-                quotes: false,
+                delimiter: None,
                 elements: vec![
                     TemplateElement::String {
                         value: "hello ".to_string(),
@@ -408,7 +439,7 @@ mod tests {
         assert_eq!(
             unquoted_template(&mut reader).unwrap(),
             Template {
-                quotes: false,
+                delimiter: None,
                 elements: vec![TemplateElement::String {
                     value: "hello world".to_string(),
                     encoded: "hello world".to_string(),
@@ -451,6 +482,18 @@ mod tests {
             }
         );
         assert_eq!(reader.state.cursor, 15);
+
+        let mut reader = Reader::init("$top:");
+        assert_eq!(
+            unquoted_string_key(&mut reader).unwrap(),
+            EncodedString {
+                value: "$top".to_string(),
+                encoded: "$top".to_string(),
+                quotes: false,
+                source_info: SourceInfo::new(1, 1, 1, 5),
+            }
+        );
+        assert_eq!(reader.state.cursor, 4);
     }
 
     #[test]
@@ -519,6 +562,16 @@ mod tests {
         let error = unquoted_string_key(&mut reader).err().unwrap();
         assert_eq!(error.pos, Pos { line: 1, column: 2 });
         assert_eq!(error.inner, ParseError::EscapeChar {});
+
+        let mut reader = Reader::init(r#"{"id":1}"#);
+        let error = unquoted_string_key(&mut reader).err().unwrap();
+        assert_eq!(error.pos, Pos { line: 1, column: 1 });
+        assert_eq!(
+            error.inner,
+            ParseError::Expecting {
+                value: "key string".to_string()
+            }
+        );
     }
 
     #[test]
@@ -527,7 +580,7 @@ mod tests {
         assert_eq!(
             quoted_template(&mut reader).unwrap(),
             Template {
-                quotes: true,
+                delimiter: Some('"'),
                 elements: vec![],
                 source_info: SourceInfo::new(1, 1, 1, 3),
             }
@@ -538,7 +591,7 @@ mod tests {
         assert_eq!(
             quoted_template(&mut reader).unwrap(),
             Template {
-                quotes: true,
+                delimiter: Some('"'),
                 elements: vec![TemplateElement::String {
                     value: "a#".to_string(),
                     encoded: "a#".to_string(),
@@ -552,7 +605,7 @@ mod tests {
         assert_eq!(
             quoted_template(&mut reader).unwrap(),
             Template {
-                quotes: true,
+                delimiter: Some('"'),
                 elements: vec![TemplateElement::String {
                     value: "{0}".to_string(),
                     encoded: "{0}".to_string(),
@@ -570,7 +623,7 @@ mod tests {
         assert_eq!(
             quoted_template(&mut reader).unwrap(),
             Template {
-                quotes: true,
+                delimiter: Some('"'),
                 elements: vec![TemplateElement::String {
                     value: "\"hi\"".to_string(),
                     encoded: "\\\"hi\\\"".to_string()
@@ -606,6 +659,80 @@ mod tests {
         assert_eq!(reader.state.cursor, 7);
     }
 
+    #[test]
+    fn test_backtick_template() {
+        let mut reader = Reader::init("``");
+        assert_eq!(
+            backtick_template(&mut reader).unwrap(),
+            Template {
+                delimiter: Some('`'),
+                elements: vec![],
+                source_info: SourceInfo::new(1, 1, 1, 3),
+            }
+        );
+        assert_eq!(reader.state.cursor, 2);
+
+        let mut reader = Reader::init("`foo#`");
+        assert_eq!(
+            backtick_template(&mut reader).unwrap(),
+            Template {
+                delimiter: Some('`'),
+                elements: vec![TemplateElement::String {
+                    value: "foo#".to_string(),
+                    encoded: "foo#".to_string(),
+                }],
+                source_info: SourceInfo::new(1, 1, 1, 7),
+            }
+        );
+        assert_eq!(reader.state.cursor, 6);
+
+        let mut reader = Reader::init("`{0}`");
+        assert_eq!(
+            backtick_template(&mut reader).unwrap(),
+            Template {
+                delimiter: Some('`'),
+                elements: vec![TemplateElement::String {
+                    value: "{0}".to_string(),
+                    encoded: "{0}".to_string(),
+                }],
+                source_info: SourceInfo::new(1, 1, 1, 6),
+            }
+        );
+        assert_eq!(reader.state.cursor, 5);
+    }
+
+    #[test]
+    fn test_backtick_template_with_backtick() {
+        // `\`hi\``
+        let mut reader = Reader::init("`\\`hi\\``");
+        assert_eq!(
+            backtick_template(&mut reader).unwrap(),
+            Template {
+                delimiter: Some('`'),
+                elements: vec![TemplateElement::String {
+                    value: "`hi`".to_string(),
+                    encoded: "\\`hi\\`".to_string()
+                }],
+                source_info: SourceInfo::new(1, 1, 1, 9),
+            }
+        );
+        assert_eq!(reader.state.cursor, 8);
+    }
+
+    #[test]
+    fn test_backtick_template_error_missing_closing_backtick() {
+        let mut reader = Reader::init("`not found");
+        let error = backtick_template(&mut reader).err().unwrap();
+        assert_eq!(
+            error.pos,
+            Pos {
+                line: 1,
+                column: 11
+            }
+        );
+        assert!(!error.recoverable);
+    }
+
     #[test]
     fn test_any_char() {
         let mut reader = Reader::init("a");
