@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2022 Orange
+ * Copyright (C) 2023 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -499,7 +499,7 @@ impl Lintable<PredicateValue> for PredicateValue {
     fn lint(&self) -> PredicateValue {
         match self {
             PredicateValue::String(value) => PredicateValue::String(value.lint()),
-            PredicateValue::Raw(value) => PredicateValue::Raw(value.lint()),
+            PredicateValue::MultilineString(value) => PredicateValue::MultilineString(value.lint()),
             PredicateValue::Integer(value) => PredicateValue::Integer(*value),
             PredicateValue::Float(value) => PredicateValue::Float(value.clone()),
             PredicateValue::Bool(value) => PredicateValue::Bool(*value),
@@ -512,16 +512,56 @@ impl Lintable<PredicateValue> for PredicateValue {
     }
 }
 
-impl Lintable<RawString> for RawString {
+impl Lintable<MultilineString> for MultilineString {
     fn errors(&self) -> Vec<Error> {
         let errors = vec![];
         errors
     }
 
-    fn lint(&self) -> RawString {
-        RawString {
-            newline: self.newline.clone(),
-            value: self.value.lint(),
+    fn lint(&self) -> MultilineString {
+        match self {
+            MultilineString::OneLineText(value) => MultilineString::OneLineText(value.lint()),
+            MultilineString::Text(value) => MultilineString::Text(value.lint()),
+            MultilineString::Json(value) => MultilineString::Json(value.lint()),
+            MultilineString::Xml(value) => MultilineString::Xml(value.lint()),
+            MultilineString::GraphQl(value) => MultilineString::GraphQl(value.lint()),
+        }
+    }
+}
+
+impl Lintable<Text> for Text {
+    fn errors(&self) -> Vec<Error> {
+        let errors = vec![];
+        errors
+    }
+
+    fn lint(&self) -> Text {
+        let space = empty_whitespace();
+        let newline = self.newline.clone();
+        let value = self.value.lint();
+        Text {
+            space,
+            newline,
+            value,
+        }
+    }
+}
+
+impl Lintable<GraphQl> for GraphQl {
+    fn errors(&self) -> Vec<Error> {
+        let errors = vec![];
+        errors
+    }
+
+    fn lint(&self) -> GraphQl {
+        let space = empty_whitespace();
+        let newline = self.newline.clone();
+        let value = self.value.lint();
+        GraphQl {
+            space,
+            newline,
+            value,
+            variables: None,
         }
     }
 }
@@ -562,20 +602,14 @@ impl Lintable<Bytes> for Bytes {
     }
 
     fn lint(&self) -> Bytes {
-        //let space0 = Whitespace { value: String::from(""), source_info: SourceInfo::init(0, 0, 0, 0) };
-        //let value = self.value.lint();
-        //let line_terminator0 = self.clone().line_terminator0;
         match self {
             Bytes::File(value) => Bytes::File(value.lint()),
             Bytes::Base64(value) => Bytes::Base64(value.lint()),
             Bytes::Hex(value) => Bytes::Hex(value.lint()),
-            Bytes::Json { value } => Bytes::Json {
-                value: value.clone(),
-            },
-            Bytes::RawString(value) => Bytes::RawString(value.lint()),
-            Bytes::Xml { value } => Bytes::Xml {
-                value: value.clone(),
-            },
+            Bytes::Json(value) => Bytes::Json(value.clone()),
+            Bytes::OnelineString(value) => Bytes::OnelineString(value.lint()),
+            Bytes::MultilineString(value) => Bytes::MultilineString(value.lint()),
+            Bytes::Xml(value) => Bytes::Xml(value.clone()),
         }
     }
 }
